# Components

## What are Components?

Components are the building blocks of your application. They are reusable UI elements that can be composed together to build a UI. Components are also the unit of encapsulation for the UI, CSS, and behavior. Components for manipulating HTML, CSS, and JavaScript from Python code are provided by the `fronty` package. Components are created by subclassing the `BaseElement` class in every modules. There are available `BaseElement` for HTML elements, CSS, and JavaScript. We will learn more about components in the [customizing components](../customization/introduction.md)

## Built-in Components

Fronty provides a set of built-in components that can be used to create a UI. These components are:

- [HTML Components](./html/introduction.md)
- [CSS Components](./css/introduction.md)
- [Javascript Components](./js/introduction.md)
